ulAIGetConfigStr

Function ulAIGetConfigStr 

pub unsafe extern "C" fn ulAIGetConfigStr(
    daqDeviceHandle: DaqDeviceHandle,
    configItem: AiConfigItemStr,
    index: c_uint,
    configStr: *mut c_char,
    maxConfigLen: *mut c_uint,
) -> UlError
\ingroup AnalogInput Use with #AiConfigItemStr to retrieve configuration options as a null-terminated string. @param daqDeviceHandle the handle to the DAQ device @param configItem the configuration item to retrieve @param index either ignored or an index into the configStr @param configStr pointer to the buffer where the configuration string is copied @param maxConfigLen pointer to the value holding the maximum number of bytes to be read from the device into configStr @return The UL error code.