ulAInScanStatus

Function ulAInScanStatus 

pub unsafe extern "C" fn ulAInScanStatus(
    daqDeviceHandle: DaqDeviceHandle,
    status: *mut ScanStatus,
    xferStatus: *mut TransferStatus,
) -> UlError
Returns the status, count, and index of an A/D scan operation. @param daqDeviceHandle the handle to the DAQ device @param status the status of the background operation (idle or running) @param xferStatus a TransferStatus struct containing fields that return the current sample count, scan count, and buffer index for the specified input scan operation @return The UL error code.