ulAOutArray

Function ulAOutArray 

pub unsafe extern "C" fn ulAOutArray(
    daqDeviceHandle: DaqDeviceHandle,
    lowChan: c_int,
    highChan: c_int,
    range: *mut Range,
    flags: AOutArrayFlag,
    data: *mut f64,
) -> UlError
Writes values to a range of D/A channels. @param daqDeviceHandle the handle to the DAQ device @param lowChan first D/A channel @param highChan last D/A channel @param range D/A ranges @param flags bit mask that specifies whether to scale and/or calibrate the data @param data[] a pointer to an array that stores the data @return The UL error code.