ulCInScanStatus

Function ulCInScanStatus 

pub unsafe extern "C" fn ulCInScanStatus(
    daqDeviceHandle: DaqDeviceHandle,
    status: *mut ScanStatus,
    xferStatus: *mut TransferStatus,
) -> UlError
Returns the status of a counter input operation. @param daqDeviceHandle the handle to the DAQ device @param status the status of the background operation @param xferStatus a TransferStatus struct containing fields that return the current sample count, scan count, and buffer index for the specified input scan operation @return The UL error code.