ulCreateDaqDevice

Function ulCreateDaqDevice 

pub unsafe extern "C" fn ulCreateDaqDevice(
    daqDevDescriptor: DaqDeviceDescriptor,
) -> DaqDeviceHandle
Create a device object within the Universal Library for the DAQ device specified by the descriptor. @param daqDevDescriptor DaqDeviceDescriptor struct containing fields that describe the device @return The device handle.