ulCreateDaqDevicePtr

Function ulCreateDaqDevicePtr 

pub unsafe extern "C" fn ulCreateDaqDevicePtr(
    daqDevDescriptor: *mut DaqDeviceDescriptor,
) -> DaqDeviceHandle
Create a device object within the Universal Library for the DAQ device specified by the descriptor. This function intended to be used by languages that don’t have capability to pass structures by value. i.e LabVIEW, VB, … @param daqDevDescriptor DaqDeviceDescriptor struct containing fields that describe the device @return The device handle.