pub unsafe extern "C" fn ulCtrSetConfig(
daqDeviceHandle: DaqDeviceHandle,
configItem: CtrConfigItem,
index: c_uint,
configValue: c_longlong,
) -> UlErrorExpand description
\ingroup CounterInput Use with #CtrConfigItem to set configuration options at runtime. @param daqDeviceHandle the handle to the DAQ device @param configItem the configuration item to set @param index either ignored or an index into the \p configValue @param configValue the value to set the specified configuration item to @return The UL error code.