pub unsafe extern "C" fn ulDConfigBit(
daqDeviceHandle: DaqDeviceHandle,
portType: DigitalPortType,
bitNum: c_int,
direction: DigitalDirection,
) -> UlErrorExpand description
Configures a digital bit as input or output. @param daqDeviceHandle the handle to the DAQ device @param portType the digital port containing the bit to configure; the port must be configurable. @param bitNum the bit number within the specified port @param direction the bit direction (input or output) @return The UL error code.