ulDOutScanWait

Function ulDOutScanWait 

pub unsafe extern "C" fn ulDOutScanWait(
    daqDeviceHandle: DaqDeviceHandle,
    waitType: WaitType,
    waitParam: c_longlong,
    timeout: f64,
) -> UlError
Returns when the scan operation completes on the specified device, or the time specified by the \p timeout argument elapses. @param daqDeviceHandle the handle to the DAQ device @param waitType the wait type @param waitParam Reserved for future use @param timeout the timeout value in seconds (s); set to -1 to wait indefinitely for the scan operation to end. @return The UL error code.