pub unsafe extern "C" fn ulDaqInScan(
daqDeviceHandle: DaqDeviceHandle,
chanDescriptors: *mut DaqInChanDescriptor,
numChans: c_int,
samplesPerChan: c_int,
rate: *mut f64,
options: ScanOption,
flags: DaqInScanFlag,
data: *mut f64,
) -> UlErrorExpand description
Allows scanning of multiple input subsystems, such as analog, digital, counter, and stores the samples in an array. This method only works with devices that support synchronous input. @param daqDeviceHandle the handle to the DAQ device @param chanDescriptors[] an array of DaqInChanDescriptor structs with fields for channel number, type, and range that specifies the order and parameters for each channel in the scan @param numChans the number of channels in the scan @param samplesPerChan the number of samples to collect from each channel in the scan @param rate sample rate in samples per channel. Upon return, this value is set to the actual sample rate. @param options scan options @param flags bit mask that specifies whether to scale data, calibrate data, or clear the counter at the start of each scan. @param data[] pointer to the buffer that receives the data @return The UL error code.