ulDaqInScanStatus

Function ulDaqInScanStatus 

pub unsafe extern "C" fn ulDaqInScanStatus(
    daqDeviceHandle: DaqDeviceHandle,
    status: *mut ScanStatus,
    xferStatus: *mut TransferStatus,
) -> UlError
Returns the status of a synchronous input operation. @param daqDeviceHandle the handle to the DAQ device @param status the status of the background operation @param xferStatus TransferStatus struct containing fields that return the current sample count, scan count, and buffer index for the specified input scan operation @return The UL error code.