pub unsafe extern "C" fn ulDaqInSetTrigger(
daqDeviceHandle: DaqDeviceHandle,
type_: TriggerType,
trigChanDescriptor: DaqInChanDescriptor,
level: f64,
variance: f64,
retriggerSampleCount: c_uint,
) -> UlErrorExpand description
Configures the trigger parameters that will be used when ulDaqInScan() is called with the ::SO_RETRIGGER or ::SO_EXTTRIGGER ScanOption. @param daqDeviceHandle the handle to the DAQ device @param type the trigger type @param trigChanDescriptor the DaqInChanDescriptor struct with fields for channel number, type, and range that defines the trigger input @param level the level at or around which the trigger event should be detected; ignored if \p type is set to ::TRIG_POS_EDGE, ::TRIG_NEG_EDGE, ::TRIG_HIGH, ::TRIG_LOW, ::GATE_HIGH, ::GATE_LOW, ::TRIG_RISING, or ::TRIG_FALLING @param variance the degree to which the input signal can vary relative to the \p level parameter; ignored for all types where \p level is ignored. For pattern triggering, this argument serves as the mask value. @param retriggerSampleCount the number of samples to acquire with each trigger event; ignored unless the ::SO_RETRIGGER ScanOption is set for the scan. @return The UL error code.