ulDevGetConfig

Function ulDevGetConfig 

pub unsafe extern "C" fn ulDevGetConfig(
    daqDeviceHandle: DaqDeviceHandle,
    configItem: DevConfigItem,
    index: c_uint,
    configValue: *mut c_longlong,
) -> UlError
Use with #DevConfigItem to retrieve the current configuration options set for a device. @param daqDeviceHandle the handle to the DAQ device @param configItem the configuration item to retrieve from the device @param index either ignored or an index into the \p configValue @param configValue the value to set the specified configuration item to @return The UL error code.