ulDisableEvent

Function ulDisableEvent 

pub unsafe extern "C" fn ulDisableEvent(
    daqDeviceHandle: DaqDeviceHandle,
    eventTypes: DaqEventType,
) -> UlError
Disables one or more event conditions, and disconnects their user-defined handlers. @param daqDeviceHandle the handle to the DAQ device @param eventTypes a bitmask containing event conditions that can be OR’d together; OR all event types to disable all events @return The UL error code.