ulMemWrite

Function ulMemWrite 

pub unsafe extern "C" fn ulMemWrite(
    daqDeviceHandle: DaqDeviceHandle,
    memRegion: MemRegion,
    address: c_uint,
    buffer: *mut c_uchar,
    count: c_uint,
) -> UlError
Writes a value to a specified region in memory. @param daqDeviceHandle the handle to the DAQ device @param memRegion memory region @param address memory address @param buffer pointer to the buffer provided by the user containing the value to write @param count number or data points to read; must be equal to or less than the size of the buffer created by the user containing the value to write @return The UL error code.