#[repr(C)]pub struct AiQueueElement {
pub channel: c_int,
pub inputMode: AiInputMode,
pub range: Range,
pub reserved: [c_char; 64],
}Expand description
\brief A structure that defines an analog input queue element
The struct contains fields defining the number, mode, and range of the A/D channel.
Fields
channel: c_intThe analog input channel number for the queue element.
inputMode: AiInputModeThe input mode to use for the specified channel for the queue element.
range: RangeThe range to use for the specified channel for the queue element.
reserved: [c_char; 64]Reserved for future use