#[repr(C)]pub struct DaqDeviceDescriptor {
pub productName: [c_char; 64],
pub productId: c_uint,
pub devInterface: DaqDeviceInterface,
pub devString: [c_char; 64],
pub uniqueId: [c_char; 64],
pub reserved: [c_char; 512],
}Expand description
\brief A structure that defines a particular DAQ device, usually obtained using ulGetDaqDeviceInventory().
The struct contains fields with the product name, ID, and interface.
Fields
productName: [c_char; 64]The generic (unqualified) product name of the device referenced by the DaqDeviceDescriptor
productId: c_uintThe numeric string indicating the product type referenced by the DaqDeviceDescriptor.
devInterface: DaqDeviceInterfaceThe enumeration indicating the type of interface in use by the device referenced by the DaqDeviceDescriptor.
devString: [c_char; 64]Similar to \p productname, but may contain additional information.
uniqueId: [c_char; 64]A string that uniquely identifies a specific device, usually with a serial number or MAC address.
reserved: [c_char; 512]Reserved for future use