#[repr(C)]pub struct DaqInChanDescriptor {
pub channel: c_int,
pub type_: DaqInChanType,
pub range: Range,
pub reserved: [c_char; 64],
}Expand description
\brief A structure that defines an input channel and its properties. Used with ulDaqInScan().
The struct contains fields for the channel number, type, and range.
Fields
channel: c_intThe channel number.
type_: DaqInChanTypeThe type of input for the specified channel, such as analog, digital, or counter.
range: RangeThe range to be used for the specified channel; ignored if not analog.
reserved: [c_char; 64]Reserved for future use