#[repr(C)]pub struct DaqOutChanDescriptor {
pub channel: c_int,
pub type_: DaqOutChanType,
pub range: Range,
pub reserved: [c_char; 64],
}Expand description
\brief A structure that defines an output channel and its properties. Used with ulDaqOutScan().
The struct contains fields for the channel number, type, and range.
Fields
channel: c_intThe channel number.
type_: DaqOutChanTypeThe type of the specified channel, such as analog or digital.
range: RangeThe range to be used for the specified channel; ignored if not analog.
reserved: [c_char; 64]Reserved for future use