#[repr(C)]pub struct MemDescriptor {
pub region: MemRegion,
pub address: c_uint,
pub size: c_uint,
pub accessTypes: MemAccessType,
pub reserved: [c_char; 64],
}Expand description
\brief A structure that defines the location and access properties of the physical memory of a device.
The struct contains fields for the memory address, size, and access type.
Fields
region: MemRegionThe enumeration indicating the region of the memory.
address: c_uintA numeric value that specifies the address of the memory; used with ulMemRead() and ulMemWrite().
size: c_uintA numeric value that specifies the size of the memory area at the specified address.
accessTypes: MemAccessTypeA bitmask indicating the access rights to the memory at the specified address (read, write, or both).
reserved: [c_char; 64]Reserved for future use