#[repr(C)]pub struct TransferStatus {
pub currentScanCount: c_ulonglong,
pub currentTotalCount: c_ulonglong,
pub currentIndex: c_longlong,
pub reserved: [c_char; 64],
}Expand description
\brief A structure containing information about the progress of the specified scan operation.
The struct contains fields for the current and total scan count and index value.
Fields
currentScanCount: c_ulonglongThe number of samples per channel transferred since the scan started. This is the same as \p currentTotalCount for single channel scans.
currentTotalCount: c_ulonglongThe total number of samples transferred since the scan started. This is the same as \p currentScanCount multiplied by the number of channels in the scan.
currentIndex: c_longlongThis marks the location in the buffer where the last scan of data values are stored. For continuous scans, this value increments up to (buffer size - number of channels) and restarts from 0.
reserved: [c_char; 64]Reserved for future use