DaqInChanType

Type Alias DaqInChanType 

pub type DaqInChanType = c_uint;
A bitmask used with synchronous input scanning operations as a field in the DaqInChanDescriptor struct, and as a value returned in the \p infoValue argument for ulDaqIGetInfo() used with ::DAQI_INFO_CHAN_TYPES.