DioConfigItem

Type Alias DioConfigItem 

pub type DioConfigItem = c_uint;
Use with ulDIOGetConfig() and/or ulDIOSetConfig() as a \p configItem argument value to get the current configuration of the specified digital port on the specified device.