pub type MemAccessType = c_uint;
A bitmask used with ulMemGetInfo() as one of the field types returned in the MemDescriptor struct. Indicates access permissions for the location specified by #MemRegion for the specified device.