Range

Type Alias Range 

pub type Range = c_uint;
Used with many analog input and output functions, as well as a return value for the \p infoValue argument to ulAIGetInfo() when used with ::AI_INFO_DIFF_RANGE or ::AI_INFO_SE_RANGE,
and the \p infoValue argument to ulAOGetInfo() when used with ::AO_INFO_RANGE.