ScanOption

Type Alias ScanOption 

pub type ScanOption = c_uint;
Used with many analog input and output functions, as well as a return value for the \p infoValue argument to many of the subsystem GetInfo functions when used with the \p infoItem argument values set to one of the subsystem INFO_SCAN_OPTIONS values.