pub unsafe extern "C" fn ulAInLoadQueue(
daqDeviceHandle: DaqDeviceHandle,
queue: *mut AiQueueElement,
numElements: c_uint,
) -> UlErrorExpand description
Loads the A/D queue of a specified device. @param daqDeviceHandle the handle to the DAQ device @param queue[] an array of AiQueueElement structs, each of which contains fields specifying channel, range, and mode @param numElements the number of elements in the queue @return The UL error code.