pub unsafe extern "C" fn ulAInScan(
daqDeviceHandle: DaqDeviceHandle,
lowChan: c_int,
highChan: c_int,
inputMode: AiInputMode,
range: Range,
samplesPerChan: c_int,
rate: *mut f64,
options: ScanOption,
flags: AInScanFlag,
data: *mut f64,
) -> UlErrorExpand description
Scans a range of A/D channels, and stores the samples in an array. @param daqDeviceHandle the handle to the DAQ device @param lowChan first A/D channel in the scan @param highChan last A/D channel in the scan @param inputMode A/D channel mode @param range A/D range @param samplesPerChan the number of A/D samples to collect from each channel in the scan @param rate A/D sample rate in samples per channel per second. Upon return, this value is set to the actual sample rate. @param options bit mask that specifies A/D scan options @param flags bit mask that specifies whether to scale and/or calibrate the data @param data[] pointer to the buffer to receive the data array @return The UL error code.