pub unsafe extern "C" fn ulAOutScan(
daqDeviceHandle: DaqDeviceHandle,
lowChan: c_int,
highChan: c_int,
range: Range,
samplesPerChan: c_int,
rate: *mut f64,
options: ScanOption,
flags: AOutScanFlag,
data: *mut f64,
) -> UlErrorExpand description
Writes values to a range of D/A channels. @param daqDeviceHandle the handle to the DAQ device @param lowChan first D/A channel in the scan @param highChan last D/A channel in the scan @param range D/A range @param samplesPerChan the number of D/A samples to output @param rate the sample rate in scans per second. Upon return, this value is set to the actual sample rate. @param options bit mask that specifies D/A scan options @param flags bit mask that specifies whether to scale and/or calibrate the data @param data[] a pointer to an array that stores the data @return The UL error code.