pub unsafe extern "C" fn ulCConfigScan(
daqDeviceHandle: DaqDeviceHandle,
counterNum: c_int,
type_: CounterMeasurementType,
mode: CounterMeasurementMode,
edgeDetection: CounterEdgeDetection,
tickSize: CounterTickSize,
debounceMode: CounterDebounceMode,
debounceTime: CounterDebounceTime,
flags: CConfigScanFlag,
) -> UlErrorExpand description
Configures a counter channel, for counters with programmable types. @param daqDeviceHandle the handle to the DAQ device @param counterNum the counter number @param type the type of counter measurement @param mode the counter mode @param edgeDetection sets the active edge of the counter input signal to positive or negative @param tickSize bit mask that specifies the counter resolution for measurement modes such as period, pulse width, and timing @param debounceMode bit mask that specifies the counter debounce mode @param debounceTime bit mask that specifies the counter debounce time @param flags bit mask that specifies counting properties such as resolution and clear on scan start @return The UL error code.