ulCInScan

Function ulCInScan 

pub unsafe extern "C" fn ulCInScan(
    daqDeviceHandle: DaqDeviceHandle,
    lowCounterNum: c_int,
    highCounterNum: c_int,
    samplesPerCounter: c_int,
    rate: *mut f64,
    options: ScanOption,
    flags: CInScanFlag,
    data: *mut c_ulonglong,
) -> UlError
Reads a range of counter channels. @param daqDeviceHandle the handle to the DAQ device @param lowCounterNum the first channel of the scan @param highCounterNum the last channel of the scan @param samplesPerCounter the number of samples per counter to read @param rate the rate in samples per second per counter. Upon return, this value is set to the actual sample rate. @param options scan options @param flags bit mask that specifies the counter scan option @param data[] pointer to the buffer to receive the data @return The UL error code.