pub unsafe extern "C" fn ulCreateDaqDevice(
daqDevDescriptor: DaqDeviceDescriptor,
) -> DaqDeviceHandleExpand description
Create a device object within the Universal Library for the DAQ device specified by the descriptor. @param daqDevDescriptor DaqDeviceDescriptor struct containing fields that describe the device @return The device handle.