pub unsafe extern "C" fn ulDIOGetConfig(
daqDeviceHandle: DaqDeviceHandle,
configItem: DioConfigItem,
index: c_uint,
configValue: *mut c_longlong,
) -> UlErrorExpand description
\ingroup DigitalIO Use with #DioConfigItem to retrieve the current configuration about the DIO subsystem. @param daqDeviceHandle the handle to the DAQ device @param configItem the configuration item to retrieve @param index the port index @param configValue the specified configuration value is returned to this variable @return The UL error code.