ulDInScan

Function ulDInScan 

pub unsafe extern "C" fn ulDInScan(
    daqDeviceHandle: DaqDeviceHandle,
    lowPort: DigitalPortType,
    highPort: DigitalPortType,
    samplesPerPort: c_int,
    rate: *mut f64,
    options: ScanOption,
    flags: DInScanFlag,
    data: *mut c_ulonglong,
) -> UlError
Reads a range of digital ports. @param daqDeviceHandle the handle to the DAQ device @param lowPort the number of the first port in the scan @param highPort the number of the last port in the scan @param samplesPerPort the number of samples to read from each port @param rate the number of times per second (Hz) to read the port. Upon return, this value is set to the actual scan rate. @param options scan options @param flags reserved for future use @param data[] pointer to an array to receive the digital data @return The UL error code.