ulDInScanStatus

Function ulDInScanStatus 

pub unsafe extern "C" fn ulDInScanStatus(
    daqDeviceHandle: DaqDeviceHandle,
    status: *mut ScanStatus,
    xferStatus: *mut TransferStatus,
) -> UlError
The status of a digital scan operation. @param daqDeviceHandle the handle to the DAQ device @param status the status of the background operation @param xferStatus a TransferStatus struct containing fields that return the current sample count, scan count, and buffer index for the specified input scan operation @return The UL error code.