pub unsafe extern "C" fn ulDOutScan(
daqDeviceHandle: DaqDeviceHandle,
lowPort: DigitalPortType,
highPort: DigitalPortType,
samplesPerPort: c_int,
rate: *mut f64,
options: ScanOption,
flags: DOutScanFlag,
data: *mut c_ulonglong,
) -> UlErrorExpand description
Writes data to a range of digital ports. @param daqDeviceHandle the handle to the DAQ device @param lowPort number of the first port in the scan @param highPort number of the last port in the scan @param samplesPerPort the number of samples per port to write @param rate the number of times per second to write to each port (scan rate). Upon return, this value is set to the actual scan rate. @param options scan options @param flags reserved for future use @param data[] a pointer to an array to receive the digital data @return The UL error code.