pub unsafe extern "C" fn ulDOutScanStatus(
daqDeviceHandle: DaqDeviceHandle,
status: *mut ScanStatus,
xferStatus: *mut TransferStatus,
) -> UlErrorExpand description
Returns the status of the digital output operation @param daqDeviceHandle the handle to the DAQ device @param status the status of the background operation @param xferStatus a TransferStatus struct containing fields that return the current sample count, scan count, and buffer index for the specified output scan operation @return The UL error code.