pub unsafe extern "C" fn ulDaqOutScan(
daqDeviceHandle: DaqDeviceHandle,
chanDescriptors: *mut DaqOutChanDescriptor,
numChans: c_int,
samplesPerChan: c_int,
rate: *mut f64,
options: ScanOption,
flags: DaqOutScanFlag,
data: *mut f64,
) -> UlErrorExpand description
Outputs values synchronously to analog output channels and digital output ports. This function only works with devices that support synchronous output. @param daqDeviceHandle the handle to the DAQ device @param chanDescriptors[] an array of DaqOutChanDescriptor structs containing fields for channel number, type, and range that specify the order and parameters for each channel in the scan @param numChans the number of channels in the scan @param samplesPerChan the number of samples per channel @param rate the sample rate in scans per second. Upon return, this value is set to the actual rate. @param options scan options @param flags bit mask that specifies whether to scale and/or calibrate data for any analog channels in the scan @param data[] buffer that holds the data that will be transferred to the device @return The UL error code.