pub unsafe extern "C" fn ulDevGetConfigStr(
daqDeviceHandle: DaqDeviceHandle,
configItem: DevConfigItemStr,
index: c_uint,
configStr: *mut c_char,
maxConfigLen: *mut c_uint,
) -> UlErrorExpand description
Use with #DevConfigItemStr to retrieve the current configuration as a null-terminated string. @param daqDeviceHandle the handle to the DAQ device @param configItem the configuration item to retrieve from the device @param index specifies the version type to return as an index into \p configItem (::DevVersionType) @param configStr pointer to the buffer where the configuration string is copied @param maxConfigLen pointer to the value specifying the size of \p configStr made available by the user; returns the number of chars written to \p configStr. @return The UL error code.