pub unsafe extern "C" fn ulGetNetDaqDeviceDescriptor(
host: *const c_char,
port: c_ushort,
ifcName: *const c_char,
daqDevDescriptor: *mut DaqDeviceDescriptor,
timeout: f64,
) -> UlErrorExpand description
Get the descriptor of the remote network DAQ device. @param host the remote device host name or IP address @param port the remote device port @param ifcName network interface name to be used for communication with the DAQ device (e.g. eth0, wlan0, …); set to NULL to select the default network interface @param daqDevDescriptor DaqDeviceDescriptor struct containing fields that describe the device @param timeout the timeout value in seconds (s); set to -1 to wait indefinitely for discovery operation to end. @return The UL error code.