pub unsafe extern "C" fn ulSetConfig(
configItem: UlConfigItem,
index: c_uint,
configValue: c_longlong,
) -> UlErrorExpand description
Use with UlConfigItem to change the library configuration options at runtime. @param configItem the type of information to write to the device @param index either ignored or an index into the \p configValue @param configValue the value to set the specified configuration item to @return The UL error code.