ulTInArray

Function ulTInArray 

pub unsafe extern "C" fn ulTInArray(
    daqDeviceHandle: DaqDeviceHandle,
    lowChan: c_int,
    highChan: c_int,
    scale: TempScale,
    flags: TInArrayFlag,
    data: *mut f64,
) -> UlError
Scans a range of A/D temperature channels, and stores the samples in an array. @param daqDeviceHandle the handle to the DAQ device @param lowChan first A/D channel in the scan @param highChan last A/D channel in the scan @param scale temperature unit @param flags reserved for future use @param data[] a pointer to an array that stores the data; if an ::ERR_OPEN_CONNECTION error occurs, the value will be -9999 in the array element associated with the channel causing the error. @return The UL error code.