pub type DaqOutChanType = c_uint;Expand description
A bitmask used with synchronous output scanning operations as a field in the DaqOutChanDescriptor struct, and as a value returned in the \p infoValue argument for ulDaqOGetInfo() used with ::DAQO_INFO_CHAN_TYPES.