pub type TriggerType = c_uint;Expand description
Used as an individual value with the subsystem SetTrigger functions as the \p type argument value, or as a bitmask value with the subsystem GetInfo functions as the \p infoValue argument value. The trigger input is specified by the \p trigChan argument, or the \p channel field of the DaqInChanDescriptor struct, when using the subsystem SetTrigger functions.